# dagster-modal

Leverage the scalable compute platform of Modal from your Dagster pipelines.

## Setup

```sh
uv venv create
source .venv/bin/activate
```

```sh
make install
```

## Test

```sh
make test
```

## Build

```sh
make build
```
